@@ -6,8 +6,6 @@ require 'mocha/deprecation'
 require 'parameter_matchers_test_helper'
 
 class BaseTest < Mocha::TestCase
-  include Mocha::ParameterMatchers::Methods
-
   def test_should_deprecate_inheriting_from_base_matcher_class
     subclass = nil
     DeprecationDisabler.disable_deprecations do
@@ -20,4 +18,5 @@ class BaseTest < Mocha::TestCase
   end
 
   include ParameterMatchersTestHelper.deprecation_tests_for_matcher_class(:Base)
+  include ParameterMatchersTestHelper.deprecation_tests_for_matcher_class(:BaseMethods)
 end
